@@ -5,6 +5,8 @@ static void _init_dict_ids(void)
 
   PyDict_SetItemString(DictIds, "symchi", Py_BuildValue("ii", AB7_INVARS_SYMCHI, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pvelmax", Py_BuildValue("ii", AB7_INVARS_PVELMAX, _DOUBLE_ARRAY));
+  PyDict_SetItemString(DictIds, "ph_freez_disp_option", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_OPTION, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "slk_rankpp", Py_BuildValue("ii", AB7_INVARS_SLK_RANKPP, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "bs_interp_rl_nb", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_RL_NB, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "slabwsrad", Py_BuildValue("ii", AB7_INVARS_SLABWSRAD, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "rfstrs", Py_BuildValue("ii", AB7_INVARS_RFSTRS, _INT_SCALAR));
@@ -32,6 +34,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "ndtset", Py_BuildValue("ii", AB7_INVARS_NDTSET, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "usepawu", Py_BuildValue("ii", AB7_INVARS_USEPAWU, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "mpw", Py_BuildValue("ii", AB7_INVARS_MPW, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "nfreqre", Py_BuildValue("ii", AB7_INVARS_NFREQRE, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawcross", Py_BuildValue("ii", AB7_INVARS_PAWCROSS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "occopt", Py_BuildValue("ii", AB7_INVARS_OCCOPT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "getddk", Py_BuildValue("ii", AB7_INVARS_GETDDK, _INT_SCALAR));
@@ -105,10 +108,11 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "efmas_ntheta", Py_BuildValue("ii", AB7_INVARS_EFMAS_NTHETA, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "tim1rev", Py_BuildValue("ii", AB7_INVARS_TIM1REV, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "mffmem", Py_BuildValue("ii", AB7_INVARS_MFFMEM, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "charge", Py_BuildValue("ii", AB7_INVARS_CHARGE, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "dfield", Py_BuildValue("ii", AB7_INVARS_DFIELD, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "dmftctqmc_grnns", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_GRNNS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "bs_exchange_term", Py_BuildValue("ii", AB7_INVARS_BS_EXCHANGE_TERM, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "charge", Py_BuildValue("ii", AB7_INVARS_CHARGE, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "imgwfstor", Py_BuildValue("ii", AB7_INVARS_IMGWFSTOR, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "getwfkfine", Py_BuildValue("ii", AB7_INVARS_GETWFKFINE, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "eph_task", Py_BuildValue("ii", AB7_INVARS_EPH_TASK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "mk1mem", Py_BuildValue("ii", AB7_INVARS_MK1MEM, _INT_SCALAR));
@@ -128,7 +132,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "recrcut", Py_BuildValue("ii", AB7_INVARS_RECRCUT, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "wvl_hgrid", Py_BuildValue("ii", AB7_INVARS_WVL_HGRID, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "userec", Py_BuildValue("ii", AB7_INVARS_USEREC, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "getxcart", Py_BuildValue("ii", AB7_INVARS_GETXCART, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "prtefmas", Py_BuildValue("ii", AB7_INVARS_PRTEFMAS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "spmeth", Py_BuildValue("ii", AB7_INVARS_SPMETH, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "npvel", Py_BuildValue("ii", AB7_INVARS_NPVEL, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "mkmem", Py_BuildValue("ii", AB7_INVARS_MKMEM, _INT_SCALAR));
@@ -138,6 +142,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "getden", Py_BuildValue("ii", AB7_INVARS_GETDEN, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "auxc_scal", Py_BuildValue("ii", AB7_INVARS_AUXC_SCAL, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "recefermi", Py_BuildValue("ii", AB7_INVARS_RECEFERMI, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "getxcart", Py_BuildValue("ii", AB7_INVARS_GETXCART, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "irdpawden", Py_BuildValue("ii", AB7_INVARS_IRDPAWDEN, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "plowan_iatom", Py_BuildValue("ii", AB7_INVARS_PLOWAN_IATOM, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "vacwidth", Py_BuildValue("ii", AB7_INVARS_VACWIDTH, _DOUBLE_SCALAR));
@@ -187,13 +192,14 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "vcutgeo", Py_BuildValue("ii", AB7_INVARS_VCUTGEO, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "tnons", Py_BuildValue("ii", AB7_INVARS_TNONS, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "efmas_dirs", Py_BuildValue("ii", AB7_INVARS_EFMAS_DIRS, _DOUBLE_ARRAY));
+  PyDict_SetItemString(DictIds, "vdw_df_threshold", Py_BuildValue("ii", AB7_INVARS_VDW_DF_THRESHOLD, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "irdwfk", Py_BuildValue("ii", AB7_INVARS_IRDWFK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ird1den", Py_BuildValue("ii", AB7_INVARS_IRD1DEN, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ntimimage", Py_BuildValue("ii", AB7_INVARS_NTIMIMAGE, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawlcutd", Py_BuildValue("ii", AB7_INVARS_PAWLCUTD, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "nband", Py_BuildValue("ii", AB7_INVARS_NBAND, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "extrapwf", Py_BuildValue("ii", AB7_INVARS_EXTRAPWF, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "pawujv", Py_BuildValue("ii", AB7_INVARS_PAWUJV, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "wvl_crmult", Py_BuildValue("ii", AB7_INVARS_WVL_CRMULT, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "dmftqmc_seed", Py_BuildValue("ii", AB7_INVARS_DMFTQMC_SEED, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "enunit", Py_BuildValue("ii", AB7_INVARS_ENUNIT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "vdw_nfrag", Py_BuildValue("ii", AB7_INVARS_VDW_NFRAG, _INT_SCALAR));
@@ -231,11 +237,11 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "userie", Py_BuildValue("ii", AB7_INVARS_USERIE, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "efmas_deg", Py_BuildValue("ii", AB7_INVARS_EFMAS_DEG, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "gw_freqsp", Py_BuildValue("ii", AB7_INVARS_GW_FREQSP, _DOUBLE_ARRAY));
-  PyDict_SetItemString(DictIds, "random_atpos", Py_BuildValue("ii", AB7_INVARS_RANDOM_ATPOS, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "symafm", Py_BuildValue("ii", AB7_INVARS_SYMAFM, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "ntypalch", Py_BuildValue("ii", AB7_INVARS_NTYPALCH, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "localrdwf", Py_BuildValue("ii", AB7_INVARS_LOCALRDWF, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "prtdosm", Py_BuildValue("ii", AB7_INVARS_PRTDOSM, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "nimage", Py_BuildValue("ii", AB7_INVARS_NIMAGE, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "nonlinear_info", Py_BuildValue("ii", AB7_INVARS_NONLINEAR_INFO, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "mdtemp", Py_BuildValue("ii", AB7_INVARS_MDTEMP, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "np_slk", Py_BuildValue("ii", AB7_INVARS_NP_SLK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "cd_halfway_freq", Py_BuildValue("ii", AB7_INVARS_CD_HALFWAY_FREQ, _DOUBLE_SCALAR));
@@ -256,8 +262,10 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "nphf", Py_BuildValue("ii", AB7_INVARS_NPHF, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "corecs", Py_BuildValue("ii", AB7_INVARS_CORECS, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "dmft_tollc", Py_BuildValue("ii", AB7_INVARS_DMFT_TOLLC, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "nimage", Py_BuildValue("ii", AB7_INVARS_NIMAGE, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "gethaydock", Py_BuildValue("ii", AB7_INVARS_GETHAYDOCK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "asr", Py_BuildValue("ii", AB7_INVARS_ASR, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "eph_frohlichm", Py_BuildValue("ii", AB7_INVARS_EPH_FROHLICHM, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "dmft_entropy", Py_BuildValue("ii", AB7_INVARS_DMFT_ENTROPY, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "gw_nstep", Py_BuildValue("ii", AB7_INVARS_GW_NSTEP, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "eph_extrael", Py_BuildValue("ii", AB7_INVARS_EPH_EXTRAEL, _DOUBLE_SCALAR));
@@ -292,6 +300,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "gwls_model_parameter", Py_BuildValue("ii", AB7_INVARS_GWLS_MODEL_PARAMETER, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "eph_mustar", Py_BuildValue("ii", AB7_INVARS_EPH_MUSTAR, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "genafm", Py_BuildValue("ii", AB7_INVARS_GENAFM, _DOUBLE_ARRAY));
+  PyDict_SetItemString(DictIds, "supercell_latt", Py_BuildValue("ii", AB7_INVARS_SUPERCELL_LATT, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "npspinor", Py_BuildValue("ii", AB7_INVARS_NPSPINOR, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ngfftdg", Py_BuildValue("ii", AB7_INVARS_NGFFTDG, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "eph_fsmear", Py_BuildValue("ii", AB7_INVARS_EPH_FSMEAR, _DOUBLE_SCALAR));
@@ -369,11 +378,12 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "nqpt", Py_BuildValue("ii", AB7_INVARS_NQPT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "dosdeltae", Py_BuildValue("ii", AB7_INVARS_DOSDELTAE, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "prtefg", Py_BuildValue("ii", AB7_INVARS_PRTEFG, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "prtkbff", Py_BuildValue("ii", AB7_INVARS_PRTKBFF, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "irdvdw", Py_BuildValue("ii", AB7_INVARS_IRDVDW, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "kptrlen", Py_BuildValue("ii", AB7_INVARS_KPTRLEN, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "kptgw", Py_BuildValue("ii", AB7_INVARS_KPTGW, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "bs_coupling", Py_BuildValue("ii", AB7_INVARS_BS_COUPLING, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "dmftctqmc_check", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_CHECK, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "irdefmas", Py_BuildValue("ii", AB7_INVARS_IRDEFMAS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "tolrde", Py_BuildValue("ii", AB7_INVARS_TOLRDE, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "getvel", Py_BuildValue("ii", AB7_INVARS_GETVEL, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "dmftbandf", Py_BuildValue("ii", AB7_INVARS_DMFTBANDF, _INT_SCALAR));
@@ -390,7 +400,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "irdddb", Py_BuildValue("ii", AB7_INVARS_IRDDDB, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "kptns_hf", Py_BuildValue("ii", AB7_INVARS_KPTNS_HF, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "gwcomp", Py_BuildValue("ii", AB7_INVARS_GWCOMP, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "wvl_crmult", Py_BuildValue("ii", AB7_INVARS_WVL_CRMULT, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "pawujv", Py_BuildValue("ii", AB7_INVARS_PAWUJV, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "mqgriddg", Py_BuildValue("ii", AB7_INVARS_MQGRIDDG, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "bs_nstates", Py_BuildValue("ii", AB7_INVARS_BS_NSTATES, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ndynimage", Py_BuildValue("ii", AB7_INVARS_NDYNIMAGE, _INT_SCALAR));
@@ -424,6 +434,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "prtphsurf", Py_BuildValue("ii", AB7_INVARS_PRTPHSURF, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ga_rules", Py_BuildValue("ii", AB7_INVARS_GA_RULES, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "wtatcon", Py_BuildValue("ii", AB7_INVARS_WTATCON, _DOUBLE_ARRAY));
+  PyDict_SetItemString(DictIds, "getefmas", Py_BuildValue("ii", AB7_INVARS_GETEFMAS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "usepaw", Py_BuildValue("ii", AB7_INVARS_USEPAW, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "smdelta", Py_BuildValue("ii", AB7_INVARS_SMDELTA, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawujrad", Py_BuildValue("ii", AB7_INVARS_PAWUJRAD, _DOUBLE_SCALAR));
@@ -473,7 +484,8 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "gwls_kmax_complement", Py_BuildValue("ii", AB7_INVARS_GWLS_KMAX_COMPLEMENT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "tolimg", Py_BuildValue("ii", AB7_INVARS_TOLIMG, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "wvl_bigdft_comp", Py_BuildValue("ii", AB7_INVARS_WVL_BIGDFT_COMP, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "prtstm", Py_BuildValue("ii", AB7_INVARS_PRTSTM, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "dmft_tolfreq", Py_BuildValue("ii", AB7_INVARS_DMFT_TOLFREQ, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "natvshift", Py_BuildValue("ii", AB7_INVARS_NATVSHIFT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "vdw_supercell", Py_BuildValue("ii", AB7_INVARS_VDW_SUPERCELL, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "acell_orig", Py_BuildValue("ii", AB7_INVARS_ACELL_ORIG, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "dmftctqmc_order", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_ORDER, _INT_SCALAR));
@@ -484,6 +496,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "efmas", Py_BuildValue("ii", AB7_INVARS_EFMAS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "vdw_df_phisoft", Py_BuildValue("ii", AB7_INVARS_VDW_DF_PHISOFT, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "prtgden", Py_BuildValue("ii", AB7_INVARS_PRTGDEN, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "prtstm", Py_BuildValue("ii", AB7_INVARS_PRTSTM, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "prtfc", Py_BuildValue("ii", AB7_INVARS_PRTFC, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "berryopt", Py_BuildValue("ii", AB7_INVARS_BERRYOPT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "prtvdw", Py_BuildValue("ii", AB7_INVARS_PRTVDW, _INT_SCALAR));
@@ -494,7 +507,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "gwls_list_proj_freq", Py_BuildValue("ii", AB7_INVARS_GWLS_LIST_PROJ_FREQ, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "rfdir", Py_BuildValue("ii", AB7_INVARS_RFDIR, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "shiftk", Py_BuildValue("ii", AB7_INVARS_SHIFTK, _DOUBLE_ARRAY));
-  PyDict_SetItemString(DictIds, "vdw_df_threshold", Py_BuildValue("ii", AB7_INVARS_VDW_DF_THRESHOLD, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "ph_freez_disp_nampl", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_NAMPL, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "kberry", Py_BuildValue("ii", AB7_INVARS_KBERRY, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "kptopt", Py_BuildValue("ii", AB7_INVARS_KPTOPT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "nspden", Py_BuildValue("ii", AB7_INVARS_NSPDEN, _INT_SCALAR));
@@ -520,12 +533,14 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "pawfatbnd", Py_BuildValue("ii", AB7_INVARS_PAWFATBND, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "omegasrdmax", Py_BuildValue("ii", AB7_INVARS_OMEGASRDMAX, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "natrd", Py_BuildValue("ii", AB7_INVARS_NATRD, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "dmft_tolfreq", Py_BuildValue("ii", AB7_INVARS_DMFT_TOLFREQ, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "usepead", Py_BuildValue("ii", AB7_INVARS_USEPEAD, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "noseinert", Py_BuildValue("ii", AB7_INVARS_NOSEINERT, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "wvl_ngauss", Py_BuildValue("ii", AB7_INVARS_WVL_NGAUSS, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "intxc", Py_BuildValue("ii", AB7_INVARS_INTXC, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "usexcnhat_orig", Py_BuildValue("ii", AB7_INVARS_USEXCNHAT_ORIG, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "mixesimgf", Py_BuildValue("ii", AB7_INVARS_MIXESIMGF, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "ixcrot", Py_BuildValue("ii", AB7_INVARS_IXCROT, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "ph_", Py_BuildValue("ii", AB7_INVARS_PH_, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "getdelfd", Py_BuildValue("ii", AB7_INVARS_GETDELFD, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "spgaxor", Py_BuildValue("ii", AB7_INVARS_SPGAXOR, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "dfpt_sciss", Py_BuildValue("ii", AB7_INVARS_DFPT_SCISS, _DOUBLE_SCALAR));
@@ -544,7 +559,6 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "pawoptmix", Py_BuildValue("ii", AB7_INVARS_PAWOPTMIX, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "optcell", Py_BuildValue("ii", AB7_INVARS_OPTCELL, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawprtdos", Py_BuildValue("ii", AB7_INVARS_PAWPRTDOS, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "prtgeo", Py_BuildValue("ii", AB7_INVARS_PRTGEO, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "mdf_epsinf", Py_BuildValue("ii", AB7_INVARS_MDF_EPSINF, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "cd_subset_freq", Py_BuildValue("ii", AB7_INVARS_CD_SUBSET_FREQ, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "berrysav", Py_BuildValue("ii", AB7_INVARS_BERRYSAV, _INT_SCALAR));
@@ -553,25 +567,25 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "prtvolimg", Py_BuildValue("ii", AB7_INVARS_PRTVOLIMG, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "lotf_classic", Py_BuildValue("ii", AB7_INVARS_LOTF_CLASSIC, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawnhatxc", Py_BuildValue("ii", AB7_INVARS_PAWNHATXC, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "natvshift", Py_BuildValue("ii", AB7_INVARS_NATVSHIFT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ionmov", Py_BuildValue("ii", AB7_INVARS_IONMOV, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "strtarget", Py_BuildValue("ii", AB7_INVARS_STRTARGET, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "vdw_df_dratio", Py_BuildValue("ii", AB7_INVARS_VDW_DF_DRATIO, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "lotf_nitex", Py_BuildValue("ii", AB7_INVARS_LOTF_NITEX, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "w90iniprj", Py_BuildValue("ii", AB7_INVARS_W90INIPRJ, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "nsppol", Py_BuildValue("ii", AB7_INVARS_NSPPOL, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "nfreqre", Py_BuildValue("ii", AB7_INVARS_NFREQRE, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "supercell", Py_BuildValue("ii", AB7_INVARS_SUPERCELL, _INT_ARRAY));
+  PyDict_SetItemString(DictIds, "hmctt", Py_BuildValue("ii", AB7_INVARS_HMCTT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "bs_coulomb_term", Py_BuildValue("ii", AB7_INVARS_BS_COULOMB_TERM, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "nbandhf", Py_BuildValue("ii", AB7_INVARS_NBANDHF, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ptgroupma", Py_BuildValue("ii", AB7_INVARS_PTGROUPMA, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "hyb_range_dft", Py_BuildValue("ii", AB7_INVARS_HYB_RANGE_DFT, _DOUBLE_SCALAR));
+  PyDict_SetItemString(DictIds, "hmcsst", Py_BuildValue("ii", AB7_INVARS_HMCSST, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "tphysel", Py_BuildValue("ii", AB7_INVARS_TPHYSEL, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "symrel", Py_BuildValue("ii", AB7_INVARS_SYMREL, _INT_ARRAY));
   PyDict_SetItemString(DictIds, "pawcpxocc", Py_BuildValue("ii", AB7_INVARS_PAWCPXOCC, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "wvl_frmult", Py_BuildValue("ii", AB7_INVARS_WVL_FRMULT, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "bs_interp_prep", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_PREP, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawusecp", Py_BuildValue("ii", AB7_INVARS_PAWUSECP, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "ph_freez_disp_ampl", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_AMPL, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "userib", Py_BuildValue("ii", AB7_INVARS_USERIB, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "rf2_dkdk", Py_BuildValue("ii", AB7_INVARS_RF2_DKDK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "so_psp", Py_BuildValue("ii", AB7_INVARS_SO_PSP, _INT_ARRAY));
@@ -604,7 +618,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "pawprt_k", Py_BuildValue("ii", AB7_INVARS_PAWPRT_K, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawoptosc", Py_BuildValue("ii", AB7_INVARS_PAWOPTOSC, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "nkpt", Py_BuildValue("ii", AB7_INVARS_NKPT, _INT_SCALAR));
-  PyDict_SetItemString(DictIds, "symafm", Py_BuildValue("ii", AB7_INVARS_SYMAFM, _INT_ARRAY));
+  PyDict_SetItemString(DictIds, "random_atpos", Py_BuildValue("ii", AB7_INVARS_RANDOM_ATPOS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawprt_b", Py_BuildValue("ii", AB7_INVARS_PAWPRT_B, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "nconeq", Py_BuildValue("ii", AB7_INVARS_NCONEQ, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "rprim_orig", Py_BuildValue("ii", AB7_INVARS_RPRIM_ORIG, _DOUBLE_ARRAY));
@@ -648,6 +662,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "nshiftk_orig", Py_BuildValue("ii", AB7_INVARS_NSHIFTK_ORIG, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "gw_qprange", Py_BuildValue("ii", AB7_INVARS_GW_QPRANGE, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "qptopt", Py_BuildValue("ii", AB7_INVARS_QPTOPT, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "chkexit", Py_BuildValue("ii", AB7_INVARS_CHKEXIT, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "eph_fermie", Py_BuildValue("ii", AB7_INVARS_EPH_FERMIE, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "prtbbb", Py_BuildValue("ii", AB7_INVARS_PRTBBB, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "ph_qshift", Py_BuildValue("ii", AB7_INVARS_PH_QSHIFT, _DOUBLE_ARRAY));
@@ -665,6 +680,7 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "prtgkk", Py_BuildValue("ii", AB7_INVARS_PRTGKK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "quadmom", Py_BuildValue("ii", AB7_INVARS_QUADMOM, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "shiftk_orig", Py_BuildValue("ii", AB7_INVARS_SHIFTK_ORIG, _DOUBLE_ARRAY));
+  PyDict_SetItemString(DictIds, "ortalg", Py_BuildValue("ii", AB7_INVARS_ORTALG, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "pawprtvol", Py_BuildValue("ii", AB7_INVARS_PAWPRTVOL, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "tolvrs", Py_BuildValue("ii", AB7_INVARS_TOLVRS, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "magconon", Py_BuildValue("ii", AB7_INVARS_MAGCONON, _INT_SCALAR));
@@ -672,6 +688,8 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "wfmix", Py_BuildValue("ii", AB7_INVARS_WFMIX, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "neb_algo", Py_BuildValue("ii", AB7_INVARS_NEB_ALGO, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "posdoppler", Py_BuildValue("ii", AB7_INVARS_POSDOPPLER, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "prtfull1wf", Py_BuildValue("ii", AB7_INVARS_PRTFULL1WF, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "ph_freez_disp_addstrain", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_ADDSTRAIN, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "bs_interp_m3_width", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_M3_WIDTH, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "recnrec", Py_BuildValue("ii", AB7_INVARS_RECNREC, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "tsmear", Py_BuildValue("ii", AB7_INVARS_TSMEAR, _DOUBLE_SCALAR));
@@ -714,12 +732,12 @@ static void _init_dict_ids(void)
   PyDict_SetItemString(DictIds, "hyb_mixing_sr", Py_BuildValue("ii", AB7_INVARS_HYB_MIXING_SR, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "ppmfrq", Py_BuildValue("ii", AB7_INVARS_PPMFRQ, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "tmesh", Py_BuildValue("ii", AB7_INVARS_TMESH, _DOUBLE_ARRAY));
-  PyDict_SetItemString(DictIds, "chkexit", Py_BuildValue("ii", AB7_INVARS_CHKEXIT, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "dmftctqmc_check", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_CHECK, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "prtdensph", Py_BuildValue("ii", AB7_INVARS_PRTDENSPH, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "vdw_df_nrpts", Py_BuildValue("ii", AB7_INVARS_VDW_DF_NRPTS, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "toldff", Py_BuildValue("ii", AB7_INVARS_TOLDFF, _DOUBLE_SCALAR));
   PyDict_SetItemString(DictIds, "toldfe", Py_BuildValue("ii", AB7_INVARS_TOLDFE, _DOUBLE_SCALAR));
-  PyDict_SetItemString(DictIds, "ortalg", Py_BuildValue("ii", AB7_INVARS_ORTALG, _INT_SCALAR));
+  PyDict_SetItemString(DictIds, "prtgeo", Py_BuildValue("ii", AB7_INVARS_PRTGEO, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "vprtrb", Py_BuildValue("ii", AB7_INVARS_VPRTRB, _DOUBLE_ARRAY));
   PyDict_SetItemString(DictIds, "mkqmem", Py_BuildValue("ii", AB7_INVARS_MKQMEM, _INT_SCALAR));
   PyDict_SetItemString(DictIds, "getdkde", Py_BuildValue("ii", AB7_INVARS_GETDKDE, _INT_SCALAR));
