@@ -9,10 +9,14 @@ need_cpp_vars = [
 keywords = [
 ]
 
+#: This suite contains tests executed with different numbers of MPI processes.
+is_multi_parallel = True
+
 #: List of input files
 inp_files = [
 "t01.in",
 "t02.in",
 "t03.in",
 "t04.in",
+"t05.in",
 ]
