@@ -2,7 +2,7 @@
 
 #: List of CPP variables that should be defined in config.h in order to enable this suite.
 need_cpp_vars = [
-"HAVE_DFT_LIBXC",
+"HAVE_LIBXC",
 ]
 
 #: List of keywords that are automatically added to all the tests of this suite. 
@@ -35,6 +35,20 @@ inp_files = [
 "t21.in",
 "t41.in",
 "t42.in", 
+"t43.in", 
+"t44.in", 
+"t45.in", 
+"t51.in", 
+"t52.in", 
+"t53.in",  
+"t67.in",  
+"t68.in",  
+"t69.in",  
+"t70.in",  
+"t71.in",  
+"t72.in", 
+"t73.in", 
+"t74.in", 
 "t81.in", 
 "t82.in", 
 ]
