@@ -24,10 +24,22 @@ inp_files = [
 "t12.in",
 "t13.in",
 "t14.in",
+"t15.in",
+"t16.in",
+"t17.in",
+"t18.in",
+"t19.in",
+"t20.in",
+"t21.in",
+"t22.in",
 "t30.in",
 "t31.in",
 "t32.in",
 "t33.in",
+"t34.in",
+"t35.in",
+"t36.in",
+"t37.in",
 "t41.in",
 "t42.in",
 "t43.in",
@@ -38,6 +50,10 @@ inp_files = [
 "t48.in",
 "t49.in",
 "t50.in",
+"t51.in",
+"t55.in",
+"t56.in",
+"t57.in",
 "t61.in",
 "t62.in",
 "t63.in",
@@ -58,6 +74,16 @@ inp_files = [
 "t78.in",
 "t79.in",
 "t80.in",
+#Nonlinear + Second order Sternheimer
+"t81.in",
+"t82.in",
+"t83.in",
+"t84.in",
+"t85.in",
+"t86.in",
+"t87.in",
+"t88.in",
+"t89.in",
 #GW-soc
 "t90.in",
 "t91.in",
